@@ -569,6 +569,7 @@ pub(super) trait TransportImpl: TransportGeneric {
             producer_id,
             rtp_capabilities,
             paused,
+            mid,
             preferred_layers,
             pipe,
             app_data,
@@ -594,14 +595,15 @@ pub(super) trait TransportImpl: TransportGeneric {
             .map_err(ConsumeError::BadConsumerRtpParameters)?;
 
             if !pipe {
-                // We use up to 8 bytes for MID (string).
-                let next_mid_for_consumers = self
-                    .next_mid_for_consumers()
-                    .fetch_add(1, Ordering::Relaxed);
-                let mid = next_mid_for_consumers % 100_000_000;
-
                 // Set MID.
-                rtp_parameters.mid = Some(format!("{}", mid));
+                rtp_parameters.mid = mid.or_else(|| {
+                    // We use up to 8 bytes for MID (string).
+                    let next_mid_for_consumers = self
+                        .next_mid_for_consumers()
+                        .fetch_add(1, Ordering::Relaxed);
+                    let mid = next_mid_for_consumers % 100_000_000;
+                    Some(format!("{}", mid))
+                })
             }
 
             rtp_parameters
