@@ -664,7 +664,7 @@ pub enum RtcpFeedback {
 }
 
 impl Serialize for RtcpFeedback {
-    fn serialize<S>(&self, serializer: S) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
         S: Serializer,
     {
@@ -700,7 +700,7 @@ impl Serialize for RtcpFeedback {
 }
 
 impl<'de> Deserialize<'de> for RtcpFeedback {
-    fn deserialize<D>(deserializer: D) -> Result<Self, <D as Deserializer<'de>>::Error>
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
     {
